import importlib
from . import raw_unscii
import glob

cached_fonts = {}

class UnsciiFont(object):
    def __init__(self, font_name):
        if font_name not in cached_fonts:
            importlib.import_module("unscii.raw_unscii.%s" % font_name, "unscii")
            module = getattr(globals()['raw_unscii'], font_name)
            cached_fonts[font_name] = getattr(module, "%s_bytes" % font_name)
        self.raw_data = cached_fonts[font_name]

    def get_char(self, char):
        return self.raw_data[ord(char)] # Is this right for unicode?
        
def unscii(font_name):
    """
    Given a font name, return a font object for usage.
    """
    return UnsciiFont(font_name)

def fonts():
    """
    Provide list of installed unscii fonts that can be used.
    """
    return raw_unscii.raw_unscii_modules



# File generate by unscii.py. Not intended to be read or modified by humans.

raw_unscii_modules = ['unscii_16_transposed',
 'unscii_8_alt_transposed',
 'unscii_8_fantasy_transposed',
 'unscii_8_mcr_transposed',
 'unscii_8_tall_transposed',
 'unscii_8_thin_transposed',
 'unscii_8_transposed']


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="unscii",
    version="0.1.0",
    author="Grant T. Olson",
    author_email="kgo@grant-olson.net",
    description="Python Interface for UNSCII bitmapped fonts",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/grant-olson/py-unscii",
    packages=setuptools.find_packages(),
    classifiers=[
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
)
